# remirepo spec file for php-pdlib
#
# Copyright (c) 2020-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%scl_package        php-pdlib
%else
%global pkg_name    %{name}
%endif

%bcond_without      tests

%global gh_commit   84436d5b9200e3388ca16851110d61b7c1439a8a
%global gh_short    %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner    goodspb
%global gh_project  pdlib
#global gh_date     20200620
%global pecl_name   pdlib
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{gh_project}-%{gh_commit}
%global _configure  ../%{sources}/configure


Summary:       A PHP extension for Dlib
Name:          %{?scl_prefix}php-%{pecl_name}
Version:       1.1.0
%if 0%{?gh_date:1}
Release:       1%{gh_date}git%{gh_short}%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%else
Release:       2%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
%endif
License:       MIT
URL:           https://github.com/%{gh_owner}/%{gh_project}
Source0:       https://github.com/%{gh_owner}/%{gh_project}/archive/%{gh_commit}/%{gh_project}-%{version}-%{gh_short}.tar.gz

%if 0%{?rhel} == 7 && 0%{?dtsversion} == 0
%global dtsversion 7
%global dtsenable source /opt/rh/devtoolset-7/enable
%global dtsprefix devtoolset-7-
BuildRequires: devtoolset-7-toolchain
%endif
BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?dtsprefix}gcc-c++
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: dlib-devel >= 19.22

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}


%description
PDlib - A PHP extension for Dlib.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

cd %{sources}
sed -e '/PHP_PDLIB_VERSION/s/1.0.2/%{version}/' -i php_pdlib.h
sed -e 's/1.0.2/%{version}/' -i tests/version.phpt

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_PDLIB_VERSION/{s/.* "//;s/".*$//;p}' php_pdlib.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
    --with-libdir=%{_lib} \
    --with-pdlib
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
    --with-libdir=%{_lib} \
    --with-pdlib
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

# Install the NTS stuff
make -C NTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

%if %{with_zts}
# Install the ZTS stuff
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif



%check
export NO_INTERACTION=1
export SKIP_ONLINE_TESTS=1
export REPORT_EXIT_STATUS=1

cd %{sources}
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
%{__php} -n run-tests.php --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with tests}
: Upstream test suite  for ZTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
%{__ztsphp} -n run-tests.php --show-diff
%endif
%endif


%files
%{!?_licensedir:%global license %%doc}
%license %{sources}/LICENSE
%doc %{sources}/README.md

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Thu Jul  6 2023 Remi Collet <remi@remirepo.net> - 1.1.0-2
- build out of sources tree
- add option to skip tests
- fix extension version

* Wed Jul  5 2023 Remi Collet <remi@remirepo.net> - 1.1.0-1
- update to 1.1.0
- drop patch merged upstream

* Thu Apr  8 2021 Remi Collet <remi@remirepo.net> - 1.0.2-6
- rebuild against dlib 19.22

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 1.0.2-5
- rebuild for PHP 8.0.0RC1
- add patch for PHP 8.0.0rc1 from
  https://github.com/goodspb/pdlib/pull/37

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 1.0.2-4
- rebuild for PHP 8.0.0beta3

* Sun Aug  9 2020 Remi Collet <remi@remirepo.net> - 1.0.2-3
- rebuild against dlib 19.21

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 1.0.2-2
- rebuild for 8.0.0beta1

* Mon Aug  3 2020 Remi Collet <remi@remirepo.net> - 1.0.2-1
- update to 1.0.2

* Mon Jul  6 2020 Remi Collet <remi@remirepo.net> - 1.0.1-1
- update to 1.0.1
- drop patches merged upstream

* Mon Jun 22 2020 Remi Collet <remi@remirepo.net> - 1.0-1.20200620git45c0b74
- new package
- open https://github.com/goodspb/pdlib/pull/25 fix linker command
- open https://github.com/goodspb/pdlib/pull/26 fix skip test
- open https://github.com/goodspb/pdlib/pull/27 display version
- open https://github.com/goodspb/pdlib/pull/29 fix build
